https://git.reactos.org/?p=reactos.git;a=commitdiff;h=5f7575909f7730aca9112e7b736951c9cc6e9fea

commit 5f7575909f7730aca9112e7b736951c9cc6e9fea
Author:     Oleg Dubinskiy <oleg.dubinskij2...@yandex.ua>
AuthorDate: Fri Aug 16 20:11:04 2019 +0300
Commit:     Hermès BÉLUSCA - MAÏTO <hermes.belusca-ma...@reactos.org>
CommitDate: Fri Aug 16 19:11:04 2019 +0200

    [AUDIOSRV][BOOTDATA][INCLUDE][MMSYS] Rename RosAudioSrv to AudioSrv (#1826)
    
    Rename RosAudioSrv to AudioSrv in audio service itself and in all system 
components which are related to this, same as it done in Win2k3.
    It allows MS DxDiag to detect the system audio service correctly, so it 
becomes possible to run DirectSound test properly with MS dsound.dll, although 
it works with some minor errors and only in older VirtualBox versions, ~ up to 
5.1.38 (and in other emulators as well).
    
    CORE-16307
---
 base/services/audiosrv/audiosrv.txt          | 14 +++++++-------
 boot/bootdata/hivesys.inf                    | 16 ++++++++--------
 dll/cpl/mmsys/mmsys.c                        |  4 ++--
 sdk/include/reactos/libs/audiosrv/audiosrv.h |  4 ++--
 4 files changed, 19 insertions(+), 19 deletions(-)

diff --git a/base/services/audiosrv/audiosrv.txt 
b/base/services/audiosrv/audiosrv.txt
index 7d3fa23ef13..37c9d24d24b 100644
--- a/base/services/audiosrv/audiosrv.txt
+++ b/base/services/audiosrv/audiosrv.txt
@@ -19,18 +19,18 @@ subsequently passes to wdmaud.drv
 It is not necessary to duplicate the exact structure of this mapped 
 file, since it appears to only be used internally by Windows components.
 
-The ROS Audio Service (RosAudioSrv) is intended to be able to run 
+The ROS Audio Service (AudioSrv) is intended to be able to run 
 alongside the Windows Audio Service on XP/Vista, so it should be 
 possible to test in a "known working environment" ;)
 
 It will create a mutex, to:
 1) Allow synchronization when accessing the device list
-2) Provide a simple method of identifying if RosAudioSrv is running
+2) Provide a simple method of identifying if AudioSrv is running
 
 (It might be worth using an event to notify WinMM when things are 
 happening?)
 
-The intention is to make RosAudioSrv receive PnP notifications for 
+The intention is to make AudioSrv receive PnP notifications for 
 relevant audio devices, and also let AudioSrv in Windows do this. Then 
 it should be possible to create a small application that imitates 
 WinMM's actions :)
@@ -54,12 +54,12 @@ Testing the Service
 ===================
 
 The service can be installed on Windows XP (possibly also Vista) like so:
-sc create RosAudioSrv <path to audiosrv.exe>
-net start RosAudioSrv
+sc create AudioSrv <path to audiosrv.exe>
+net start AudioSrv
 
 ...and can be removed like so:
-net stop RosAudioSrv
-sc delete RosAudioSrv
+net stop AudioSrv
+sc delete AudioSrv
 
 You can view a list of the currently available devices (device list is
 identical to the one offered by Windows' own AudioSrv) by running
diff --git a/boot/bootdata/hivesys.inf b/boot/bootdata/hivesys.inf
index 8f65a0ac783..dde3a8e9fd8 100644
--- a/boot/bootdata/hivesys.inf
+++ b/boot/bootdata/hivesys.inf
@@ -1521,14 +1521,14 @@ 
HKLM,"SYSTEM\CurrentControlSet\Services\swenum","Start",0x00010001,0x00000000
 HKLM,"SYSTEM\CurrentControlSet\Services\swenum","Type",0x00010001,0x00000001
 
 ; Audio Service
-HKLM,"SYSTEM\CurrentControlSet\Services\RosAudioSrv","DisplayName",0x00000000,%AUDIO_SERVICE%
-HKLM,"SYSTEM\CurrentControlSet\Services\RosAudioSrv","Description",0x00000000,%AUDIO_SERVICE_DESCRIPTION%
-HKLM,"SYSTEM\CurrentControlSet\Services\RosAudioSrv","ErrorControl",0x00010001,0x00000000
-HKLM,"SYSTEM\CurrentControlSet\Services\RosAudioSrv","Group",0x00000000,"Audio"
-HKLM,"SYSTEM\CurrentControlSet\Services\RosAudioSrv","ImagePath",0x00020000,"%SystemRoot%\system32\audiosrv.exe"
-HKLM,"SYSTEM\CurrentControlSet\Services\RosAudioSrv","ObjectName",0x00000000,"LocalSystem"
-HKLM,"SYSTEM\CurrentControlSet\Services\RosAudioSrv","Start",0x00010001,0x00000003
-HKLM,"SYSTEM\CurrentControlSet\Services\RosAudioSrv","Type",0x00010001,0x00000010
+HKLM,"SYSTEM\CurrentControlSet\Services\AudioSrv","DisplayName",0x00000000,%AUDIO_SERVICE%
+HKLM,"SYSTEM\CurrentControlSet\Services\AudioSrv","Description",0x00000000,%AUDIO_SERVICE_DESCRIPTION%
+HKLM,"SYSTEM\CurrentControlSet\Services\AudioSrv","ErrorControl",0x00010001,0x00000000
+HKLM,"SYSTEM\CurrentControlSet\Services\AudioSrv","Group",0x00000000,"Audio"
+HKLM,"SYSTEM\CurrentControlSet\Services\AudioSrv","ImagePath",0x00020000,"%SystemRoot%\system32\audiosrv.exe"
+HKLM,"SYSTEM\CurrentControlSet\Services\AudioSrv","ObjectName",0x00000000,"LocalSystem"
+HKLM,"SYSTEM\CurrentControlSet\Services\AudioSrv","Start",0x00010001,0x00000003
+HKLM,"SYSTEM\CurrentControlSet\Services\AudioSrv","Type",0x00010001,0x00000010
 
 ; Background Intelligent Transfer Service (BITS)
 
HKLM,"SYSTEM\CurrentControlSet\Services\BITS","DisplayName",0x00000000,%BITS_SERVICE%
diff --git a/sdk/include/reactos/libs/audiosrv/audiosrv.h 
b/sdk/include/reactos/libs/audiosrv/audiosrv.h
index 057ce3e4300..016f9cddd54 100644
--- a/sdk/include/reactos/libs/audiosrv/audiosrv.h
+++ b/sdk/include/reactos/libs/audiosrv/audiosrv.h
@@ -11,8 +11,8 @@
 #ifndef AUDIOSRV_H
 #define AUDIOSRV_H
 
-/* This is currently set to avoid conflicting service names in Windows! */
-#define SERVICE_NAME                L"RosAudioSrv"
+/* The service name */
+#define SERVICE_NAME                L"AudioSrv"
 
 /* A named mutex is used for synchronizing access to the device list.
    If this mutex doesn't exist, it means the audio service isn't running. */

Reply via email to
diff --git a/dll/cpl/mmsys/mmsys.c b/dll/cpl/mmsys/mmsys.c
index e2d7c8e5391..7b8ab726446 100644
--- a/dll/cpl/mmsys/mmsys.c
+++ b/dll/cpl/mmsys/mmsys.c
@@ -553,10 +553,10 @@ MMSYS_InstallDevice(HDEVINFO hDevInfo, PSP_DEVINFO_DATA 
pspDevInfoData)
         return ERROR_DI_DO_DEFAULT;
     }
 
-    hService = OpenService(hSCManager, L"RosAudioSrv", SERVICE_ALL_ACCESS);
+    hService = OpenService(hSCManager, L"AudioSrv", SERVICE_ALL_ACCESS);
     if (hService)
     {
         /* Make RosAudioSrv start automatically */
         ChangeServiceConfig(hService, SERVICE_NO_CHANGE, SERVICE_AUTO_START, 
SERVICE_NO_CHANGE, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
 
@@ -553,10 +553,10 @@ MMSYS_InstallDevice(HDEVINFO hDevInfo, PSP_DEVINFO_DATA 
     if (hService)
     {
-        /* Make RosAudioSrv start automatically */
+        /* Make AudioSrv start automatically */
         ChangeServiceConfig(hService, SERVICE_NO_CHANGE, SERVICE_AUTO_START, 
SERVICE_NO_CHANGE, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
         StartService(hService, 0, NULL);